@@ -1,4 +1,3 @@
-# -*- coding: iso-8859-1 -*-
 # Copyright (C) 2004-2014 Bastian Kleineidam
 #
 # This program is free software; you can redistribute it and/or modify
@@ -24,21 +23,21 @@ from linkcheck.checker.fileurl import get_nt_filename
 from . import need_windows
 
 
-class TestFilenames (unittest.TestCase):
+class TestFilenames(unittest.TestCase):
     """
     Test filename routines.
     """
 
     @need_windows
-    def test_nt_filename (self):
+    def test_nt_filename(self):
         path = os.getcwd()
         realpath = get_nt_filename(path)
         self.assertEqual(path, realpath)
-        path = 'c:\\'
+        path = "c:\\"
         realpath = get_nt_filename(path)
         self.assertEqual(path, realpath)
         # XXX Only works on my computer.
         # Is there a Windows UNC share that is always available for tests?
-        #path = '\\Vboxsrv\share\msg.txt'
-        #realpath = get_nt_filename(path)
-        #self.assertEqual(path, realpath)
+        # path = '\\Vboxsrv\share\msg.txt'
+        # realpath = get_nt_filename(path)
+        # self.assertEqual(path, realpath)
